@@ -7,7 +7,9 @@ describe 'octavia::quota' do
       :default_listener_quota       => '<SERVICE DEFAULT>',
       :default_member_quota         => '<SERVICE DEFAULT>',
       :default_pool_quota           => '<SERVICE DEFAULT>',
-      :default_health_monitor_quota => '<SERVICE DEFAULT>'
+      :default_health_monitor_quota => '<SERVICE DEFAULT>',
+      :default_l7policy_quota       => '<SERVICE DEFAULT>',
+      :default_l7rule_quota         => '<SERVICE DEFAULT>',
     }
   end
 
@@ -27,6 +29,8 @@ describe 'octavia::quota' do
       is_expected.to contain_octavia_config('quotas/default_member_quota').with_value(p[:default_member_quota])
       is_expected.to contain_octavia_config('quotas/default_pool_quota').with_value(p[:default_pool_quota])
       is_expected.to contain_octavia_config('quotas/default_health_monitor_quota').with_value(p[:default_health_monitor_quota])
+      is_expected.to contain_octavia_config('quotas/default_l7policy_quota').with_value(p[:default_l7policy_quota])
+      is_expected.to contain_octavia_config('quotas/default_l7rule_quota').with_value(p[:default_l7rule_quota])
     end
 
     context 'configure quota with parameters' do
@@ -36,16 +40,20 @@ describe 'octavia::quota' do
           :default_listener_quota       => 20,
           :default_member_quota         => 30,
           :default_pool_quota           => 40,
-          :default_health_monitor_quota => 50
+          :default_health_monitor_quota => 50,
+          :default_l7policy_quota       => 60,
+          :default_l7rule_quota         => 70,
         })
       end
 
-      it 'contains overrided values' do
+      it 'contains the defined values' do
         is_expected.to contain_octavia_config('quotas/default_load_balancer_quota').with_value(p[:default_load_balancer_quota])
         is_expected.to contain_octavia_config('quotas/default_listener_quota').with_value(p[:default_listener_quota])
         is_expected.to contain_octavia_config('quotas/default_member_quota').with_value(p[:default_member_quota])
         is_expected.to contain_octavia_config('quotas/default_pool_quota').with_value(p[:default_pool_quota])
         is_expected.to contain_octavia_config('quotas/default_health_monitor_quota').with_value(p[:default_health_monitor_quota])
+        is_expected.to contain_octavia_config('quotas/default_l7policy_quota').with_value(p[:default_l7policy_quota])
+        is_expected.to contain_octavia_config('quotas/default_l7rule_quota').with_value(p[:default_l7rule_quota])
       end
     end
   end
